aboutsummaryrefslogtreecommitdiff
path: root/src/tools/mac/crash_report/on_demand_symbol_supplier.h
diff options
context:
space:
mode:
authormmentovai <mmentovai@4c0a9323-5329-0410-9bdc-e9ce6186880e>2007-02-14 19:51:05 +0000
committermmentovai <mmentovai@4c0a9323-5329-0410-9bdc-e9ce6186880e>2007-02-14 19:51:05 +0000
commite5dc60822e5938fea2ae892ccddb906641ba174e (patch)
treed7d4a8e94fee7bdb4eee6501221d92595ebd5f02 /src/tools/mac/crash_report/on_demand_symbol_supplier.h
parentChange the symbol table parsing so that it will only use symbols that are fro... (diff)
downloadbreakpad-e5dc60822e5938fea2ae892ccddb906641ba174e.tar.xz
Rename Airbag to Breakpad.
git-svn-id: http://google-breakpad.googlecode.com/svn/trunk@122 4c0a9323-5329-0410-9bdc-e9ce6186880e
Diffstat (limited to 'src/tools/mac/crash_report/on_demand_symbol_supplier.h')
-rw-r--r--src/tools/mac/crash_report/on_demand_symbol_supplier.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/tools/mac/crash_report/on_demand_symbol_supplier.h b/src/tools/mac/crash_report/on_demand_symbol_supplier.h
index 0cd78f58..22c3c825 100644
--- a/src/tools/mac/crash_report/on_demand_symbol_supplier.h
+++ b/src/tools/mac/crash_report/on_demand_symbol_supplier.h
@@ -28,16 +28,16 @@
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
// on_demand_symbol_supplier.h: Provides a Symbol Supplier that will create
// an airbag symbol file on demand.
#ifndef TOOLS_MAC_CRASH_REPORT_ON_DEMAND_SYMBOL_SUPPLIER_H__
#define TOOLS_MAC_CRASH_REPORT_ON_DEMAND_SYMBOL_SUPPLIER_H__
#include <map>
#include <string>
-#include "google_airbag/processor/symbol_supplier.h"
+#include "google_breakpad/processor/symbol_supplier.h"
-namespace google_airbag {
+namespace google_breakpad {
using std::map;
using std::string;
@@ -79,12 +79,12 @@ class OnDemandSymbolSupplier : public SymbolSupplier {
// returned, then |module| doesn't have a symbol file.
string GetModuleSymbolFile(const CodeModule *module);
// Generate the airbag symbol file for |module|. Return true if successful.
// File is generated in /tmp.
bool GenerateSymbolFile(const CodeModule *module,
const SystemInfo *system_info);
};
-} // namespace google_airbag
+} // namespace google_breakpad
#endif // TOOLS_MAC_CRASH_REPORT_ON_DEMAND_SYMBOL_SUPPLIER_H__
@@ -28,16 +28,16 @@
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
// on_demand_symbol_supplier.h: Provides a Symbol Supplier that will create
-// an airbag symbol file on demand.
+// an breakpad symbol file on demand.
#ifndef TOOLS_MAC_CRASH_REPORT_ON_DEMAND_SYMBOL_SUPPLIER_H__
#define TOOLS_MAC_CRASH_REPORT_ON_DEMAND_SYMBOL_SUPPLIER_H__
@@ -79,12 +79,12 @@ class OnDemandSymbolSupplier : public SymbolSupplier {
// returned, then |module| doesn't have a symbol file.
string GetModuleSymbolFile(const CodeModule *module);
- // Generate the airbag symbol file for |module|. Return true if successful.
+ // Generate the breakpad symbol file for |module|. Return true if successful.
// File is generated in /tmp.
bool GenerateSymbolFile(const CodeModule *module,